==> klayout_0.28.16.orig.tar.gz: klayout-0.28.16/scripts/mkqtdecl5/QtDesigner/allofqt.cpp <==
#include "QtDesigner/QAbstractExtensionFactory"
#include "QtDesigner/QAbstractExtensionManager"
#include "QtDesigner/QAbstractFormBuilder"
#if 0
//  No designer support, except QFormBuilder
#include "QtDesigner/QDesignerActionEditorInterface"
#include "QtDesigner/QDesignerComponents"
#include "QtDesigner/QDesignerContainerExtension"
#include "QtDesigner/QDesignerDnDItemInterface"
#include "QtDesigner/QDesignerDynamicPropertySheetExtension"
#include "QtDesigner/QDesignerExtraInfoExtension"
#include "QtDesigner/QDesignerFormEditorInterface"
#include "QtDesigner/QDesignerFormEditorPluginInterface"
#include "QtDesigner/QDesignerFormWindowCursorInterface"
#include "QtDesigner/QDesignerFormWindowInterface"
#include "QtDesigner/QDesignerFormWindowManagerInterface"
#include "QtDesigner/QDesignerFormWindowToolInterface"
#include "QtDesigner/QDesignerIntegration"
#include "QtDesigner/QDesignerIntegrationInterface"
#include "QtDesigner/QDesignerLanguageExtension"
#include "QtDesigner/QDesignerLayoutDecorationExtension"
#include "QtDesigner/QDesignerMemberSheetExtension"
#include "QtDesigner/QDesignerMetaDataBaseInterface"
#include "QtDesigner/QDesignerMetaDataBaseItemInterface"
#include "QtDesigner/QDesignerNewFormWidgetInterface"
#include "QtDesigner/QDesignerObjectInspectorInterface"
#include "QtDesigner/QDesignerOptionsPageInterface"
#include "QtDesigner/QDesignerPromotionInterface"
#include "QtDesigner/QDesignerPropertyEditorInterface"
#include "QtDesigner/QDesignerPropertySheetExtension"
#include "QtDesigner/QDesignerResourceBrowserInterface"
#include "QtDesigner/QDesignerSettingsInterface"
#include "QtDesigner/QDesignerTaskMenuExtension"
#include "QtDesigner/QDesignerWidgetBoxInterface"
#include "QtDesigner/QDesignerWidgetDataBaseInterface"
#include "QtDesigner/QDesignerWidgetDataBaseItemInterface"
#include "QtDesigner/QDesignerWidgetFactoryInterface"
#include "QtDesigner/QExtensionFactory"
#include "QtDesigner/QExtensionManager"
#endif
#include "QtDesigner/QFormBuilder"
#if 0
#include "QtDesigner/QtDesigner"
#include "QtDesigner/QtDesignerDepends"
#include "QtDesigner/QtDesignerVersion"
#endif

==> klayout_0.30.0.orig.tar.gz: klayout-0.30.0/scripts/mkqtdecl5/QtDesigner/allofqt.cpp <==
#if 0
//  No designer support, except QFormBuilder
#include "QtDesigner/QAbstractExtensionFactory"
#include "QtDesigner/QAbstractExtensionManager"
#include "QtDesigner/QAbstractFormBuilder"
#include "QtDesigner/QDesignerActionEditorInterface"
#include "QtDesigner/QDesignerComponents"
#include "QtDesigner/QDesignerContainerExtension"
#include "QtDesigner/QDesignerCustomWidgetCollectionInterface"
#include "QtDesigner/QDesignerCustomWidgetInterface"
#include "QtDesigner/QDesignerDnDItemInterface"
#include "QtDesigner/QDesignerDynamicPropertySheetExtension"
#include "QtDesigner/QDesignerExportWidget"
#include "QtDesigner/QDesignerExtraInfoExtension"
#include "QtDesigner/QDesignerFormEditorInterface"
#include "QtDesigner/QDesignerFormEditorPluginInterface"
#include "QtDesigner/QDesignerFormWindowCursorInterface"
#include "QtDesigner/QDesignerFormWindowInterface"
#include "QtDesigner/QDesignerFormWindowManagerInterface"
#include "QtDesigner/QDesignerFormWindowToolInterface"
#include "QtDesigner/QDesignerIntegration"
#include "QtDesigner/QDesignerIntegrationInterface"
#include "QtDesigner/QDesignerLanguageExtension"
#include "QtDesigner/QDesignerLayoutDecorationExtension"
#include "QtDesigner/QDesignerMemberSheetExtension"
#include "QtDesigner/QDesignerMetaDataBaseInterface"
#include "QtDesigner/QDesignerMetaDataBaseItemInterface"
#include "QtDesigner/QDesignerNewFormWidgetInterface"
#include "QtDesigner/QDesignerObjectInspectorInterface"
#include "QtDesigner/QDesignerOptionsPageInterface"
#include "QtDesigner/QDesignerPromotionInterface"
#include "QtDesigner/QDesignerPropertyEditorInterface"
#include "QtDesigner/QDesignerPropertySheetExtension"
#include "QtDesigner/QDesignerResourceBrowserInterface"
#include "QtDesigner/QDesignerSettingsInterface"
#include "QtDesigner/QDesignerTaskMenuExtension"
#include "QtDesigner/QDesignerWidgetBoxInterface"
#include "QtDesigner/QDesignerWidgetDataBaseInterface"
#include "QtDesigner/QDesignerWidgetDataBaseItemInterface"
#include "QtDesigner/QDesignerWidgetFactoryInterface"
#include "QtDesigner/QExtensionFactory"
#include "QtDesigner/QExtensionManager"
#endif
#include "QtDesigner/QFormBuilder"
#if 0
#include "QtDesigner/QtDesigner"
#include "QtDesigner/QtDesignerDepends"
#include "QtDesigner/QtDesignerVersion"
#endif
